SimpleJITProduct

Struct SimpleJITProduct 

pub struct SimpleJITProduct { /* private fields */ }
A SimpleJITProduct allows looking up the addresses of all functions and data objects defined in the original module.

Implementations

Source

impl SimpleJITProduct

pub unsafe fn free_memory(&mut self)

Free memory allocated for code and data segments of compiled functions.

Safety

Because this function invalidates any pointers retrived from the corresponding module, it should only be used when none of the functions from that module are currently executing and none of the fn pointers are called afterwards.

pub fn func_or_data_for_func(&self, name: &str) -> Option<FuncOrDataId>

Get the FuncOrDataId associated with the given name.

pub fn lookup_func(&self, func_id: FuncId) -> *const u8

Return the address of a function.

pub fn lookup_data(&self, data_id: DataId) -> (*const u8, usize)

Return the address and size of a data object.